@@ -1,6 +1,7 @@
 import asyncio
 import logging
 from typing import Dict, List
+
 from .lupusec_service import LupusecSevice
 from .lupusec_types import DeviceClass, LupuDevice, AlarmForm
 
@@ -8,11 +9,12 @@ _LOGGER = logging.getLogger("LupusecStateMachine")
 
 
 class LupusecStateMachine:
-    __devicesDict:Dict[DeviceClass, List[LupuDevice]] = dict()
-    __panels:AlarmForm=None
-    def __init__(self, username, password, ip_address, time):
+    __devicesDict: Dict[DeviceClass, List[LupuDevice]] = dict()
+    __panels: AlarmForm = None
+
+    def __init__(self, ip_address, username, password, time):
         self.__time = time
-        self.__lupu_service = LupusecSevice(username, password, ip_address)
+        self.__lupu_service = LupusecSevice(ip_address, username, password)
         loop = asyncio.get_event_loop()
         loop.run_until_complete(self.__poll_devices())
         loop.run_until_complete(self.__poll_panels())
